@@ -8,7 +8,7 @@ from vial.middleware import CallChain, MiddlewareAPI, MiddlewareChain
 from vial.parsers import ParserAPI
 from vial.resources import Resource
 from vial.routes import Route, RoutingAPI
-from vial.types import HTTPMethod, Json, LambdaContext, Request, Response
+from vial.types import HTTPMethod, Json, LambdaContext, MultiDict, Request, Response
 
 
 class NativeJson(Json):
@@ -103,7 +103,7 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI):
         self.error_handler = self.error_handler_class()
         self.invoker = self.invoker_class()
         self.json = self.json_class()
-        self.logger = self.logger_factory_class.get(__name__)
+        self.logger = self.logger_factory_class.get(name)
 
     def register_resource(self, app: Resource) -> None:
         ParserAPI.register_parsers(self, app)
@@ -146,7 +146,7 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI):
             HTTPMethod[event["httpMethod"]],
             event["resource"],
             event["path"],
-            event["headers"],
-            event["queryStringParameters"],
+            MultiDict(event["multiValueHeaders"]),
+            MultiDict(event["multiValueQueryStringParameters"]),
             event["body"],
         )
